UncheckedIndexing

Struct UncheckedIndexing 

pub struct UncheckedIndexing;
Unchecked indexing strategy for sequences.

In this mode, the Seq<T> includes only the storage for the T objects, and nothing else. It is not possible to check integer offsets for validity in this mode, so only unsafe unchecked indexing is available.

Examples

use varlen::prelude::*;

let mut seq = Seq::new_minimal();
seq.push(Str::copy("hello"));
let pos = seq.offset();
seq.push(Str::copy("world"));
// Safe because: first element is always at offset 0.
assert_eq!("hello", unsafe { &seq.from_offset_unchecked(0)[..] });
// Safe because: offset() returned offset of the next element to be pushed.
assert_eq!("world", unsafe { &seq.from_offset_unchecked(pos)[..] });